==> deepin-camera_6.0.11.tar.xz: BUILD/src/translations/deepin-camera_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>تسجيل الفيديو قيد التقدم. إغلاق النافذة؟</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">فتح مجلد</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
    <message>
        <source>None</source>
        <translation>لا أحد</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>إغلاق</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>فتح مجلد</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>طباعة</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>ليس لديك إذن لتشغيل هذا المجلد</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>إغلاق</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">مجلد غير صالح</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>فتح مجلد</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>الأساسية</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>موقع الملف</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>التقط</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>صور سريعة متتالية</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>مؤقت التقاط صورة شخصية</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>الناتج</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>نوع امتداد الناتج</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 قطع</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 قطع</translation>
    </message>
    <message>
        <source>None</source>
        <translation>لا أحد</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>كاميرا</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>الكاميرا هي أداة التقاط الصور والفيديو باستخدام كاميرا الحاسوب أو كاميرا الويب.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>لم يتم حفظ المِلَفّ</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">حفظ ل:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>صورة:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>فيديو:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>إعدادات الدِّقَّة</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">الدِّقَّة:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>صور:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>مقاطع فيديو:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>مؤثرات صوتية</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>كاميرا</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>العدادات</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>إيقاف التسجيل</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>فتح</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>طباعة</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>مساعدة</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>عرض الاختصارات</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>إيقاف التقاط الصور</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>قائمة السياق</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">التقاط صورة</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">تسجيل فيديو</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">إيقاف التقاط الصور</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>لا أحد</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation>لا أحد</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>لم يتم العثور على أية كاميرا ويب</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>كاميرا ويب قيد الاستخدام</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">إيقاف التسجيل</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>تسجيل الفيديو قيد التقدم. إغلاق النافذة؟</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">فتح مجلد</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
    <message>
        <source>None</source>
        <translation>لا أحد</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>صورة</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>فيديو</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>تبديل الكاميرات</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>إغلاق</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>فتح مجلد</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>طباعة</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>ليس لديك إذن لتشغيل هذا المجلد</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>إغلاق</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">مجلد غير صالح</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>فتح مجلد</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>الأساسية</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>موقع الملف</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>التقط</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>صور سريعة متتالية</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>مؤقت التقاط صورة شخصية</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>الناتج</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>نوع امتداد الناتج</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 قطع</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 قطع</translation>
    </message>
    <message>
        <source>None</source>
        <translation>لا أحد</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>كاميرا</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>الكاميرا هي أداة التقاط الصور والفيديو باستخدام كاميرا الحاسوب أو كاميرا الويب.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>لم يتم حفظ المِلَفّ</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">حفظ إلى:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>صورة:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>فيديو:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>إعدادات الدِّقَّة</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">الدِّقَّة:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>صور:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>مقاطع فيديو:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>مؤثرات صوتية</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>وضع المرآة</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>مصباح يدوي</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>شبكة</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>خطوط 1x1</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>خطوط 2x2</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>أقصى دقة</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>كاميرا</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>العدادات</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>إيقاف التسجيل</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>فتح</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>طباعة</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>مساعدة</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>عرض الاختصارات</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>إيقاف التقاط الصور</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>قائمة السياق</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">التقاط صورة</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">تسجيل فيديو</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">إيقاف التقاط الصور</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>لا أحد</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>طبيعي</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>براق</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation> دافئ</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>بارد</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>ستيني</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>فيلم</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>رمادي</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>أبيض وأسود</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>مصباح يدوي</translation>
    </message>
    <message>
        <source>On</source>
        <translation> eingeschaltet</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>ausgeschaltet</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>التقاط التأخير</translation>
    </message>
    <message>
        <source>None</source>
        <translation>لا أحد</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>الفلاتر</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>النوافذ</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>لم يتم العثور على أية كاميرا ويب</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>كاميرا ويب قيد الاستخدام</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">إيقاف التسجيل</translation>
    </message>
</context>
</TS>
